## [2.0.1] - 2026-02-10

### Added
- Add flags for delete, create, update, query

### Changed
- Linting
- Update readme
- Setup the snyk module

### Removed
- Remove circular dependency injenction

## New Contributors
* @ made their first contribution
